package com.jiuqi.util;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.nio.ByteBuffer;
import java.nio.channels.Channels;
import java.nio.channels.FileChannel;
import java.nio.channels.WritableByteChannel;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/FileClassLoader.class */
public class FileClassLoader extends ClassLoader {
    private String baseDir;

    public FileClassLoader(String baseDir) {
        this.baseDir = baseDir;
    }

    public FileClassLoader(ClassLoader parent, String baseDir) {
        super(parent);
        this.baseDir = baseDir;
    }

    @Override // java.lang.ClassLoader
    protected Class findClass(String name) throws ClassNotFoundException {
        byte[] bytes = loadClassBytes(name);
        Class theClass = null;
        try {
            theClass = defineClass(name, bytes, 0, bytes.length);
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (theClass == null) {
            throw new ClassFormatError();
        }
        return theClass;
    }

    private byte[] loadClassBytes(String className) throws ClassNotFoundException {
        try {
            String classFile = getClassFile(className);
            FileInputStream fis = new FileInputStream(classFile);
            FileChannel fileC = fis.getChannel();
            ByteArrayOutputStream baos = new ByteArrayOutputStream();
            WritableByteChannel outC = Channels.newChannel(baos);
            ByteBuffer buffer = ByteBuffer.allocateDirect(1024);
            while (true) {
                int i = fileC.read(buffer);
                if (i == 0 || i == -1) {
                    break;
                }
                buffer.flip();
                outC.write(buffer);
                buffer.clear();
            }
            fis.close();
            return baos.toByteArray();
        } catch (IOException fnfe) {
            throw new ClassNotFoundException(className, fnfe);
        }
    }

    private String getClassFile(String name) {
        StringBuffer sb = new StringBuffer(this.baseDir);
        sb.append(String.valueOf(File.separator) + (String.valueOf(name.replace('.', File.separatorChar)) + ".class"));
        return sb.toString();
    }

    @Override // java.lang.ClassLoader
    protected URL findResource(String name) {
        try {
            URL url = super.findResource(name);
            if (url != null) {
                return url;
            }
            return new URL("file:///" + converName(name));
        } catch (MalformedURLException unused) {
            return null;
        }
    }

    private String converName(String name) {
        StringBuffer sb = new StringBuffer(this.baseDir);
        sb.append(String.valueOf(File.separator) + name.replace('.', File.separatorChar));
        return sb.toString();
    }
}
